API Reference
=============

.. autoclass:: vonage.Client
   :members:
   :undoc-members:

   .. attribute:: application_v2

      An instance of :class:`vonage.ApplicationV2` for accessing the Application API.

.. autoclass:: vonage.ApplicationV2
    :members:
    :undoc-members:
